@@ -57,4 +57,4 @@ class Hotspot():
                 data = Api().get_hotspot_rewards(self.address, max_time, min_time, cursor)["data"]
                 self.rewards = data
                 #self.rewards_cursor = data["cursor"]
-                return self.rewards, self.rewards_cursor
\ No newline at end of file
+                return self.rewards
\ No newline at end of file
